View source: R/run-ed50-analysis.R
| get_ed50_by_grouping_property | R Documentation |
This function takes a list of models and extracts the ED50 value for each model based on a specified grouping property. The ED50 value is extracted from the model's coefficients and is associated with the intercept term.
get_ed50_by_grouping_property(models)
models |
A list of models where each element represents a model object containing coefficients. |
A data frame containing the ED50 values along with their corresponding grouping property. Each row represents a model's ED50 value and its associated grouping property.
data(cbass_dataset)
preprocessed_data <- preprocess_dataset(cbass_dataset)
model_list <-fit_drms(preprocessed_data,
c("Site", "Condition", "Species", "Genotype"),
"Pam_value ~ Temperature")
ed50_data <- get_ed50_by_grouping_property(model_list)
# Resulting data frame structure:
# ED50 GroupingProperty
# 1 ED50_value_1 Group1
# 2 ED50_value_2 Group2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.